@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-01-15'; # DATE
+our $DATE = '2023-02-09'; # DATE
 our $DIST = 'App-MetaCPANUtils'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use File::chdir;
 
@@ -236,6 +236,8 @@ sub list_recent_metacpan_releases {
     require MetaCPAN::Client;
 
     my %args = @_;
+    # XXX schema, sync with schema's
+    $args{fields} //= [ map {$_->[0]} grep {$_->[2]} @$release_fields ];
 
     my $mcpan = MetaCPAN::Client->new;
     log_trace "[MetaCPAN::Client] Requesting recent %d release(s) ...", $args{n};
@@ -245,6 +247,16 @@ sub list_recent_metacpan_releases {
 
 $SPEC{list_metacpan_releases} = {
     v => 1.1,
+    summary => 'List releases',
+    description => <<'_',
+
+Some notes:
+
+- MetaCPAN often returns multiple releases of the same distribution with `first`
+  field set to 1, so if you only want to find the first release of a
+  distribution you'll need to filter out the extraneous results.
+
+_
     args => {
         %argopt_release_fields,
         %argopt_release_sort,
@@ -257,6 +269,12 @@ $SPEC{list_metacpan_releases} = {
         %argoptf_release_status,
         %argoptf_first,
     },
+    args_rels => {
+        'choose_one&' => [
+            ['from_date', 'date'],
+            ['to_date', 'date'],
+        ],
+    },
     examples => [
         {
             summary => 'Show releases in December 2020',
@@ -273,17 +291,14 @@ $SPEC{list_metacpan_releases} = {
             'x.doc.show_result' => 0,
         },
     ],
-    args_rels => {
-        'choose_one&' => [
-            ['from_date', 'date'],
-            ['to_date', 'date'],
-        ],
-    },
 };
 sub list_metacpan_releases {
     require MetaCPAN::Client;
 
     my %args = @_;
+    # XXX schema, sync with schema's
+    $args{sort} //= '-date';
+    $args{fields} //= [ map {$_->[0]} grep {$_->[2]} @$release_fields ];
 
     my $mcpan = MetaCPAN::Client->new;
 
@@ -317,6 +332,7 @@ sub list_metacpan_releases {
 
 $SPEC{list_metacpan_distributions} = {
     v => 1.1,
+    summary => 'List distributions',
     args => {
         %argopt_distribution_fields,
         %argopt_distribution_sort,
@@ -329,6 +345,9 @@ sub list_metacpan_distributions {
     require MetaCPAN::Client;
 
     my %args = @_;
+    # XXX schema, keep in sync with schema's
+    $args{sort} //= 'distribution';
+    $args{fields} //= [ map {$_->[0]} grep {$_->[2]} @$distribution_fields ];
 
     my $mcpan = MetaCPAN::Client->new;
 
@@ -350,6 +369,7 @@ sub list_metacpan_distributions {
 
 $SPEC{list_metacpan_modules} = {
     v => 1.1,
+    summary => 'List modules',
     args => {
         %argopt_module_fields,
         %argopt_module_sort,
@@ -373,6 +393,9 @@ sub list_metacpan_modules {
     require MetaCPAN::Client;
 
     my %args = @_;
+    # XXX schema, keep sync with schema's
+    $args{sort} //= 'module';
+    $args{fields} //= [ map {$_->[0]} grep {$_->[2]} @$module_fields ];
 
     my $mcpan = MetaCPAN::Client->new;
 
@@ -579,6 +602,12 @@ $SPEC{diff_metacpan_releases} = {
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            summary => 'Compare the latest version of Log::Any released by JSWARTZ and the latest version released by DAGOLDEN',
+            argv => ['Log-Any', 'author="JSWARTZ"', 'author="DAGOLDEN"'],
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
     ],
     'x.envs' => {
         'DIFF_METACPAN_RELEASES_DEBUG' => {
@@ -639,7 +668,7 @@ App::MetaCPANUtils - CLI utilities related to MetaCPAN
 
 =head1 VERSION
 
-This document describes version 0.007 of App::MetaCPANUtils (from Perl distribution App-MetaCPANUtils), released on 2023-01-15.
+This document describes version 0.008 of App::MetaCPANUtils (from Perl distribution App-MetaCPANUtils), released on 2023-02-09.
 
 =head1 DESCRIPTION
 
@@ -692,6 +721,14 @@ Examples:
    version2     => "latest"
  );
 
+=item * Compare the latest version of Log::Any released by JSWARTZ and the latest version released by DAGOLDEN:
+
+ diff_metacpan_releases(
+     distribution => "Log-Any",
+   version1     => "author=\"JSWARTZ\"",
+   version2     => "author=\"DAGOLDEN\""
+ );
+
 =back
 
 This function is not exported.
@@ -829,6 +866,8 @@ Usage:
 
  list_metacpan_distributions(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
+List distributions.
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
@@ -869,6 +908,8 @@ Usage:
 
  list_metacpan_modules(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
+List modules.
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
@@ -921,6 +962,18 @@ Usage:
 
  list_metacpan_releases(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
+List releases.
+
+Some notes:
+
+=over
+
+=item * MetaCPAN often returns multiple releases of the same distribution with C<first>
+field set to 1, so if you only want to find the first release of a
+distribution you'll need to filter out the extraneous results.
+
+=back
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
